@@ -5,7 +5,7 @@ use Mojo::Collection 'c';
 use DBI;
 use Carp qw(croak);
   
-our $VERSION  = '0.02';
+our $VERSION  = '0.03';
 
 sub new {
 	my $class = shift;
@@ -19,7 +19,7 @@ sub new {
 		croak qq/invalid MojoX::Mysql object/;
 	}
 
-	if(exists $args{'table'} && $args{'table'} && $args{'table'} =~ m/^[0-9a-z_-]+$/){
+	if(exists $args{'table'} && $args{'table'} && $args{'table'} =~ m/^[0-9a-z_-]+$/i){
 		$config->{'table'} = $args{'table'};
 	}
 	else{
